package sun.awt.windows;

import java.awt.datatransfer.UnsupportedFlavorException;
import java.util.Iterator;
import java.util.SortedMap;
import java.io.IOException;
import java.io.NotSerializableException;
import java.awt.datatransfer.DataFlavor;
import sun.awt.datatransfer.DataTransferer;
import java.awt.datatransfer.Transferable;
import sun.awt.datatransfer.SunClipboard;

final class WClipboard extends SunClipboard
{
    private boolean isClipboardViewerRegistered;
    
    WClipboard() {
        super("System");
    }
    
    @Override
    public long getID() {
        return 0L;
    }
    
    @Override
    protected void setContentsNative(Transferable transferable) {
        SortedMap<Long, DataFlavor> formatsForTransferable = DataTransferer.getInstance().getFormatsForTransferable(transferable, SunClipboard.getDefaultFlavorTable());
        this.openClipboard(this);
        try {
            for (Long n : formatsForTransferable.keySet()) {
                DataFlavor flavor = (DataFlavor)formatsForTransferable.get(n);
                try {
                    this.publishClipboardData((long)n, DataTransferer.getInstance().translateTransferable(transferable, flavor, (long)n));
                }
                catch (IOException ex) {
                    if (!flavor.isMimeTypeEqual("application/x-java-jvm-local-objectref") || !(ex instanceof NotSerializableException)) {
                        ex.printStackTrace();
                    }
                    else {
                        continue;
                    }
                }
            }
        }
        finally {
            this.closeClipboard();
        }
    }
    
    private void lostSelectionOwnershipImpl() {
        this.lostOwnershipImpl();
    }
    
    @Override
    protected void clearNativeContext() {
    }
    
    @Override
    public native void openClipboard(SunClipboard p0) throws IllegalStateException;
    
    @Override
    public native void closeClipboard();
    
    private native void publishClipboardData(long p0, byte[] p1);
    
    private static native void init();
    
    @Override
    protected native long[] getClipboardFormats();
    
    @Override
    protected native byte[] getClipboardData(long p0) throws IOException;
    
    @Override
    protected void registerClipboardViewerChecked() {
        if (!this.isClipboardViewerRegistered) {
            this.registerClipboardViewer();
            this.isClipboardViewerRegistered = true;
        }
    }
    
    private native void registerClipboardViewer();
    
    @Override
    protected void unregisterClipboardViewerChecked() {
    }
    
    private void handleContentsChanged() {
        if (!this.areFlavorListenersRegistered()) {
            return;
        }
        long[] clipboardFormats = null;
        try {
            this.openClipboard(null);
            clipboardFormats = this.getClipboardFormats();
        }
        catch (IllegalStateException ex) {}
        finally {
            this.closeClipboard();
        }
        this.checkChange(clipboardFormats);
        return;
    }
    
    @Override
    protected Transferable createLocaleTransferable(long[] array) throws IOException {
        boolean n = false;
        int i = 0;
        while (i < array.length) {
            if (array[i] == 16L) {
                n = true;
                break;
            }
            ++i;
        }
        if (n == 0) {
            return null;
        }
        final byte[] clipboardData;
        try {
            clipboardData = this.getClipboardData(16L);
        }
        catch (IOException ex) {
            return null;
        }
        return new Transferable() {
            @Override
            public DataFlavor[] getTransferDataFlavors() {
                return new DataFlavor[] { DataTransferer.javaTextEncodingFlavor };
            }
            
            @Override
            public boolean isDataFlavorSupported(DataFlavor dataFlavor) {
                return dataFlavor.equals(DataTransferer.javaTextEncodingFlavor);
            }
            
            @Override
            public Object getTransferData(DataFlavor flavor) throws UnsupportedFlavorException {
                if (this.isDataFlavorSupported(flavor)) {
                    return clipboardData;
                }
                throw new UnsupportedFlavorException(flavor);
            }
        };
    }
    
    static {
        init();
    }
}
